@@ -21,6 +21,8 @@
            (bless { name => 'op5', service => 'sv2', port => 'pt4' }, MyXML::Operation),
           )
     }
+    sub importDefinitions {
+    }
 };
 {
     package MyXML::Operation;
@@ -40,5 +42,8 @@
         my $self = shift;
         return $self->{name};
     }
+    sub soapStyle {
+        'document'
+    }
 };
 1;
